# CHANGELOG

## 0.1.0

* Add raw_render() function ton inject yaml without yamlfu rendering
* Add -e VARNAME1,VARNAME2 to import environment variables (closes #1)

## 0.0.3

* Automated release using github actions

## 0.0.1

* Initial commit
